@@ -3,7 +3,6 @@ import re
 from openshift.dynamic.exceptions import ConflictError
 
 from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
 from ocp_resources.node import Node
 from ocp_resources.node_network_configuration_enactment import (
     NodeNetworkConfigurationEnactment,
@@ -13,9 +12,6 @@ from ocp_resources.resource import Resource, ResourceEditor
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
-
-
 class NNCPConfigurationFailed(Exception):
     pass
 
@@ -296,7 +292,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             func=self.update,
             resource_dict=resource,
         )
-        LOGGER.info(f"Applying {resource}")
+        self.logger.info(f"Applying {resource}")
         for _ in samples:
             return
 
@@ -304,12 +300,12 @@ class NodeNetworkConfigurationPolicy(Resource):
         self.ipv4_ports_backup()
         self.ipv6_ports_backup()
 
-        self.create(body=self.res, wait=wait)
+        self.create(wait=wait)
         try:
             self.wait_for_status_success()
             return self
         except Exception as exp:
-            LOGGER.error(exp)
+            self.logger.error(exp)
             super().__exit__(exception_type=None, exception_value=None, traceback=None)
             raise
 
@@ -319,7 +315,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                 self._absent_interface()
                 self.wait_for_status_success()
             except Exception as exp:
-                LOGGER.error(exp)
+                self.logger.error(exp)
 
         super().clean_up()
 
@@ -394,7 +390,7 @@ class NodeNetworkConfigurationPolicy(Resource):
         try:
             for sample in samples:
                 if sample == self.Conditions.Reason.SUCCESSFULLY_CONFIGURED:
-                    LOGGER.info(f"NNCP {self.name} configured Successfully")
+                    self.logger.info(f"NNCP {self.name} configured Successfully")
                     return sample
 
                 elif sample == no_match_node_condition_reason:
@@ -408,7 +404,7 @@ class NodeNetworkConfigurationPolicy(Resource):
                     )
 
         except (TimeoutExpiredError, NNCPConfigurationFailed):
-            LOGGER.error(
+            self.logger.error(
                 f"Unable to configure NNCP {self.name} "
                 f"{f'nodes: {[node.name for node in self.nodes]}' if self.nodes else ''}"
             )
@@ -453,7 +449,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             try:
                 nnce.wait_for_conditions()
             except TimeoutExpiredError:
-                LOGGER.error(f"Failed to get NNCE {nnce.name} status")
+                self.logger.error(f"Failed to get NNCE {nnce.name} status")
                 continue
 
             for nnce_cond in nnce.instance.status.conditions:
